
from machine import ADC, I2C, Pin, PWM
import time
from pico_i2c_lcd import I2cLcd

pressure_sensor = ADC(Pin(26, mode=Pin.IN))
hall_sensor = Pin(27, Pin.IN, Pin.PULL_UP)
btnn_reset = Pin(22, Pin.IN)
lcd = False
buzzer_satus = False
ii = 0


def interruption_handler(*args, **kargs):
    global ii
    ii += 1
    
hall_sensor.irq(
    handler=interruption_handler,
    trigger=Pin.IRQ_RISING,
)
previous_time = time.ticks_ms()


def setup():
    global pressure_sensor, lcd, buzzer
    i2c = I2C(0, sda=Pin(0), scl=Pin(1), freq=100000)
    I2C_ADDR = i2c.scan()[0]
    lcd = I2cLcd(i2c, I2C_ADDR, 2, 16)
    buzzer = PWM(Pin(15))
    buzzer.duty_u16(0)
    

def get_rotation_frequency():
    global ii, previous_time
    frequency = float(ii) / (time.ticks_ms() - previous_time) * 1e3
    previous_time = time.ticks_ms()
    ii = 0
    return frequency


def get_pressure():
    global pressure_sensor
    pressure_measure = float(pressure_sensor.read_u16()) / 65535 * 3.3
    return pressure_measure


def loop():
    global lcd, buzzer, buzzer_satus
    pressure_measure = get_pressure()
    lcd.clear()
    str_pressure = "{:.3f}".format(pressure_measure)
    lcd.putstr('Preassure: ' + str_pressure + '\n')
    frequency = get_rotation_frequency()
    str_frequency = "{:.3f}".format(frequency)
    lcd.putstr('Frequency: ' + str_frequency)
    time.sleep(.07)
    buzzer_satus = not buzzer_satus
    if buzzer_satus:
        buzzer.duty_u16(220)
    else:
        buzzer.duty_u16(0)
    


def handle_error():
    global lcd
    lcd.putstr('Exception')


if __name__ == "__main__":
    setup()
    try:
    	while(True):
            loop()
    except:
        handle_error()
        while True:
            pass

